==> claromentis-framework-9.6.6-26891208.zip: web/intranet/documents/classes/backup/BackupCollection.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_a0c574277fd3c2720" . "a40f6e1ba4e33f5" => base64_decode("U0VMRUNUIGlkIEZST00gYmFja3" . "VwX3Nlcmllcw=="));





class BackupCollection implements IteratorAggregate
{
    protected $items = [];
    
    
    
    
    public function Load($_82eb4a68a9db5431865bed0c5837de30 = true)
    {
        global $db;
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_a0c574277fd3c2" . "720a40f6e1ba4e3" . "3f5"]);
        while ($_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchRow()) {
            $_20eedf73e25dd0dfcc2236fcba14aff4 = new BackupSingleSeries();
            try {
                $_20eedf73e25dd0dfcc2236fcba14aff4->Load($_b8cfc2e06d9d1fec1893ea4a054002bf[0]);
                $_b3332fc4b021e81f555e2958f9534536 = $_20eedf73e25dd0dfcc2236fcba14aff4->GetSeriesFolders();
                if (!empty($_b3332fc4b021e81f555e2958f9534536)) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                } elseif (empty($_b3332fc4b021e81f555e2958f9534536) && $_82eb4a68a9db5431865bed0c5837de30) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                }
            } catch (BackupException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
                $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                $_20eedf73e25dd0dfcc2236fcba14aff4->eh->ProcessError($_fe441aa3ef350bfb1a1a1ad8520dd530->getCode(), $_fe441aa3ef350bfb1a1a1ad8520dd530->getData());
            }
        }
    }
    
    
    public function getIterator()
    {
        return new ArrayIterator($this->items);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/documents/classes/backup/BackupCollection.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_a0c574277fd3c2720a40f" . "6e1ba4e33f5" => base64_decode("U0VMRUNUIGlkIEZST00" . "gYmFja3VwX3Nlcmllcw" . "=="));





class BackupCollection implements IteratorAggregate
{
    protected $items = [];
    
    
    
    
    public function Load($_82eb4a68a9db5431865bed0c5837de30 = true)
    {
        global $db;
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_a0c574277fd3c2720a40f6e1ba" . "4e33f5"]);
        while ($_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchRow()) {
            $_20eedf73e25dd0dfcc2236fcba14aff4 = new BackupSingleSeries();
            try {
                $_20eedf73e25dd0dfcc2236fcba14aff4->Load($_b8cfc2e06d9d1fec1893ea4a054002bf[0]);
                $_b3332fc4b021e81f555e2958f9534536 = $_20eedf73e25dd0dfcc2236fcba14aff4->GetSeriesFolders();
                if (!empty($_b3332fc4b021e81f555e2958f9534536)) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                } elseif (empty($_b3332fc4b021e81f555e2958f9534536) && $_82eb4a68a9db5431865bed0c5837de30) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                }
            } catch (BackupException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
                $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                $_20eedf73e25dd0dfcc2236fcba14aff4->eh->ProcessError($_fe441aa3ef350bfb1a1a1ad8520dd530->getCode(), $_fe441aa3ef350bfb1a1a1ad8520dd530->getData());
            }
        }
    }
    
    
    public function getIterator()
    {
        return new ArrayIterator($this->items);
    }
}
